print("import: 'botocore'")
import botocore

print("import: 'botocore.docs'")
import botocore.docs

print("import: 'botocore.docs.bcdoc'")
import botocore.docs.bcdoc

print("import: 'botocore.vendored'")
import botocore.vendored

print("import: 'botocore.vendored.requests'")
import botocore.vendored.requests

print("import: 'botocore.vendored.requests.packages'")
import botocore.vendored.requests.packages

print("import: 'botocore.vendored.requests.packages.chardet'")
import botocore.vendored.requests.packages.chardet

print("import: 'botocore.vendored.requests.packages.urllib3'")
import botocore.vendored.requests.packages.urllib3

print("import: 'botocore.vendored.requests.packages.urllib3.contrib'")
import botocore.vendored.requests.packages.urllib3.contrib

print("import: 'botocore.vendored.requests.packages.urllib3.packages'")
import botocore.vendored.requests.packages.urllib3.packages

print("import: 'botocore.vendored.requests.packages.urllib3.packages.ssl_match_hostname'")
import botocore.vendored.requests.packages.urllib3.packages.ssl_match_hostname

print("import: 'botocore.vendored.requests.packages.urllib3.util'")
import botocore.vendored.requests.packages.urllib3.util

